/* -*- mode: c++; indent-tabs-mode: nil -*- */
/** @file QC_UUID.qpp UUID class definition

  uuid Qore module

  Copyright (C) 2010 - 2012 David Nichols

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "uuid-module.h"
/* Qore class Qore::UUID::UUID */

qore_classid_t CID_UUID;
QoreClass* QC_UUID;

// nothing UUID::clear(){}
static AbstractQoreNode* UUID_clear(QoreObject* self, QoreUUID* uuid, const QoreListNode* args, ExceptionSink* xsink) {
# 142 "QC_UUID.qpp"
    uuid->clear();
    return 0;
}

// int UUID::compare(UUID other){}
static int64 UUID_compare_C4UUID(QoreObject* self, QoreUUID* uuid, const QoreListNode* args, ExceptionSink* xsink) {
    HARD_QORE_OBJ_DATA(other, QoreUUID, args, 0, CID_UUID, "UUID::compare()", "UUID", xsink);
    if (*xsink)
        return 0;
# 173 "QC_UUID.qpp"
    SimpleRefHolder<QoreUUID> holder(other);

   return uuid->compare(*other);
}

// UUID::constructor(int flags = Qore::UUID::None) {}
static void UUID_constructor_Vi(QoreObject* self, const QoreListNode* args, ExceptionSink* xsink) {
    int64 flags = HARD_QORE_INT(args, 0);
# 79 "QC_UUID.qpp"
self->setPrivate(CID_UUID, new QoreUUID((int)flags));
}

// UUID::constructor(string uuid_str) {}
static void UUID_constructor_Vs(QoreObject* self, const QoreListNode* args, ExceptionSink* xsink) {
    const QoreStringNode* uuid_str = HARD_QORE_STRING(args, 0);
# 94 "QC_UUID.qpp"
SimpleRefHolder<QoreUUID> uuid(new QoreUUID(*uuid_str, xsink));
   if (*xsink)
      return;
 
   self->setPrivate(CID_UUID, uuid.release());
}

// UUID::copy() {}
static void UUID_copy(QoreObject* self, QoreObject* old, QoreUUID* uuid, ExceptionSink* xsink) {
# 109 "QC_UUID.qpp"
self->setPrivate(CID_UUID, new QoreUUID(*uuid));
}

// nothing UUID::generate(int flags = Qore::UUID::None){}
static AbstractQoreNode* UUID_generate_Vi(QoreObject* self, QoreUUID* uuid, const QoreListNode* args, ExceptionSink* xsink) {
    int64 flags = HARD_QORE_INT(args, 0);
# 159 "QC_UUID.qpp"
    uuid->generate((int)flags);
    return 0;
}

// bool UUID::isNull(){}
static bool UUID_isNull(QoreObject* self, QoreUUID* uuid, const QoreListNode* args, ExceptionSink* xsink) {
# 135 "QC_UUID.qpp"
    return uuid->isNull();
}

// nothing UUID::set(string uuid_str){}
static AbstractQoreNode* UUID_set_Vs(QoreObject* self, QoreUUID* uuid, const QoreListNode* args, ExceptionSink* xsink) {
    const QoreStringNode* uuid_str = HARD_QORE_STRING(args, 0);
# 189 "QC_UUID.qpp"
    uuid->set(*uuid_str, xsink);
    return 0;
}

// string UUID::toString(int flag = Qore::UUID::LowerCase){}
static AbstractQoreNode* UUID_toString_Vi(QoreObject* self, QoreUUID* uuid, const QoreListNode* args, ExceptionSink* xsink) {
    int64 flag = HARD_QORE_INT(args, 0);
# 123 "QC_UUID.qpp"
    return uuid->toString((int)flag);
}

// static string UUID::get(int str_flag = Qore::UUID::LowerCase, int gen_flags = Qore::UUID::None){}
static AbstractQoreNode* static_UUID_get_ViVi(const QoreListNode* args, ExceptionSink* xsink) {
    int64 str_flag = HARD_QORE_INT(args, 0);
    int64 gen_flags = HARD_QORE_INT(args, 1);
# 199 "QC_UUID.qpp"
return QoreUUID::get((int)str_flag, (int)gen_flags);
}

DLLLOCAL void preinitUUIDClass() {
    QC_UUID = new QoreClass("UUID", QDOM_DEFAULT);
    CID_UUID = QC_UUID->getID();
    QC_UUID->setSystem();
}

DLLLOCAL QoreClass* initUUIDClass(QoreNamespace& ns) {
    if (!QC_UUID)
        preinitUUIDClass();

    // nothing UUID::clear(){}
    QC_UUID->addMethodExtended3("clear", (q_method_t)UUID_clear, false, QC_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo);

    // int UUID::compare(UUID other){}
    QC_UUID->addMethodExtended3("compare", (q_method_int64_t)UUID_compare_C4UUID, false, QC_CONSTANT, QDOM_DEFAULT, bigIntTypeInfo, 1, QC_UUID->getTypeInfo(), NULL, "other");

    // UUID::constructor(int flags = Qore::UUID::None) {}
    QC_UUID->setConstructorExtended3(UUID_constructor_Vi, false, QC_NO_FLAGS, QDOM_DEFAULT, 1, bigIntTypeInfo, new QoreBigIntNode(QUF_NONE), "flags");

    // UUID::constructor(string uuid_str) {}
    QC_UUID->setConstructorExtended3(UUID_constructor_Vs, false, QC_NO_FLAGS, QDOM_DEFAULT, 1, stringTypeInfo, NULL, "uuid_str");

    // UUID::copy() {}
    QC_UUID->setCopy((q_copy_t)UUID_copy);

    // nothing UUID::generate(int flags = Qore::UUID::None){}
    QC_UUID->addMethodExtended3("generate", (q_method_t)UUID_generate_Vi, false, QC_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 1, bigIntTypeInfo, new QoreBigIntNode(QUF_NONE), "flags");

    // bool UUID::isNull(){}
    QC_UUID->addMethodExtended3("isNull", (q_method_bool_t)UUID_isNull, false, QC_CONSTANT, QDOM_DEFAULT, boolTypeInfo);

    // nothing UUID::set(string uuid_str){}
    QC_UUID->addMethodExtended3("set", (q_method_t)UUID_set_Vs, false, QC_NO_FLAGS, QDOM_DEFAULT, nothingTypeInfo, 1, stringTypeInfo, NULL, "uuid_str");

    // string UUID::toString(int flag = Qore::UUID::LowerCase){}
    QC_UUID->addMethodExtended3("toString", (q_method_t)UUID_toString_Vi, false, QC_CONSTANT, QDOM_DEFAULT, stringTypeInfo, 1, bigIntTypeInfo, new QoreBigIntNode(QUF_LOWER_CASE), "flag");

    // static string UUID::get(int str_flag = Qore::UUID::LowerCase, int gen_flags = Qore::UUID::None){}
    QC_UUID->addStaticMethodExtended3("get", (q_func_t)static_UUID_get_ViVi, false, QC_CONSTANT, QDOM_DEFAULT, stringTypeInfo, 2, bigIntTypeInfo, new QoreBigIntNode(QUF_LOWER_CASE), "str_flag", bigIntTypeInfo, new QoreBigIntNode(QUF_NONE), "gen_flags");
# 26 "QC_UUID.qpp"
# 33 "QC_UUID.qpp"
# 36 "QC_UUID.qpp"
# 39 "QC_UUID.qpp"
    ns.addConstant("Empty", new QoreBigIntNode(QUF_EMPTY));
    ns.addConstant("HAVE_UNPARSE_CASE", &True);
    ns.addConstant("None", new QoreBigIntNode(QUF_NONE));
    ns.addConstant("Random", new QoreBigIntNode(QUF_RANDOM));
    ns.addConstant("Time", new QoreBigIntNode(QUF_TIME));
# 46 "QC_UUID.qpp"
    ns.addConstant("LowerCase", new QoreBigIntNode(QUF_LOWER_CASE));
    ns.addConstant("UpperCase", new QoreBigIntNode(QUF_UPPER_CASE));

    return QC_UUID;
}
